searchData={"items":[{"type":"module","title":"TinyMaps","doc":"","ref":"TinyMaps.html"},{"type":"module","title":"TinyMaps - TinyMaps","doc":"_A successor to the [shorter_maps](https://github.com/meyercm/shorter_maps) package._\n\n`~M` sigil for map shorthand. `~M{a} ~> %{a: a}`\n\n[![Build Status](https://travis-ci.org/meyercm/shorter_maps.svg?branch=master)](https://travis-ci.org/meyercm/shorter_maps)","ref":"TinyMaps.html#module-tinymaps"},{"type":"module","title":"Getting started - TinyMaps","doc":"1. Add `{:tiny_maps, \"~> 3.0\"},` to your mix deps\n2. Add `import TinyMaps` to the top of your module\n3. DRY up your maps and structs with `~M` and `~m`. Instead of `%{name: name}`\n   use `~M{name}`, and for `%{\"name\" => name}` use `~m{name}`. When the key and\n   the variable don't match, don't fret: `~M{name, id: current_id}` expands\n   to `%{name: name, id: current_id}`.","ref":"TinyMaps.html#module-getting-started"},{"type":"module","title":"Motivation - TinyMaps","doc":"Code like `%{id: id, name: name, address: address}` occurs with high frequency\nin many programming languages. In Elixir, additional uses occur as we pattern\nmatch to destructure existing maps.\n\nES6 provided javascript with a shorthand to create maps with keys inferred by\nvariable names, and allowed destructuring those maps into variables named for\nthe keys. `TinyMaps` provides that functionality to Elixir.","ref":"TinyMaps.html#module-motivation"},{"type":"module","title":"Syntax: - TinyMaps","doc":"`~M` and `~m` can be used to replace maps **anywhere** in your code. The\n`TinyMaps` sigil syntax operates just like a vanilla elixir map, with two\nmain differences:\n\n1. When a variable name stands alone, it is replaced with a key-value pair,\n   where the key is the variable name as a string (~m) or an atom (~M). The value\n   will be the variable. For example, `~M{name, id: get_free_id()}` expands to\n   `%{name: name, id: get_free_id()}`.\n\n2. Struct names are enclosed in the sigil, rather than outside, e.g.:\n   `~M{%StructName key, key2}` === `%StructName{key: key, key2: key2}`. The\n   struct name must be followed by a space, and then comma-separated keys.\n   Structs can be updated just like maps: `~M{%StructName old_struct|key_to_update}`","ref":"TinyMaps.html#module-syntax"},{"type":"module","title":"Examples - TinyMaps","doc":"```elixir\niex> import TinyMaps\n...> name = \"Chris\"\n...> id = 6\n...> ~M{name, id}\n%{name: \"Chris\", id: 6}\n\n# It's ok to mix in other expressions:\n...> ~M{name, id: id + 200}\n%{name: \"Chris\", id: 206}\n\n# or even nest the sigil (note the change in delimiters to paren):\n...> ~M{name, id, extra_copy: ~M(name, id)}\n%{name: \"Chris\", id: 6, extra_copy: %{name: \"Chris\", id: 6}}\n\n# We can use String keys:\n...> ~m{name, id}\n%{\"name\" => \"Chris\", \"id\" => 6}\n\n# And we can update existing maps:\n...> map_1 = %{name: \"Bob\", id: 9}\n...> ~M{map_1|name}\n%{name: \"Chris\", id: 9}\n\n# Struct syntax is a little funky:\n...> defmodule MyStruct do\n...>   defstruct [id: nil, name: :default]\n...> end\n...> ~M{%MyStruct id}\n%MyStruct{id: 6, name: :default}\n\n# Structs can be updated too:\n...> initial_struct = %MyStruct{name: \"Chris\", id: :unknown}\n...> ~M{%MyStruct initial_struct|id}\n%MyStruct{name: \"Chris\", id: 6}\n\n# Because the expansion happens at compile time, they can be used __anywhere__:\n\n# in function heads:\n...> defmodule MyModule do\n...>   def my_func(~M{name, _id}), do: {:id_present, name}\n...>   def my_func(~M{name}), do: {:no_id, name}\n...> end\n\n# in pattern matches:\n...> ~M{age, model} = %{age: -30, model: \"Delorean\", manufacturer: \"AMC\"}\n...> age\n-30\n\n```","ref":"TinyMaps.html#module-examples"},{"type":"module","title":"Credits - TinyMaps","doc":"TinyMaps is continuation of the [ShorterMaps](https://github.com/meyercm/shorter_maps) which has become unmaintained and I have not been able to make contact with the maintainer.\n\nShorterMaps added additional features to the original project, `ShortMaps`,\nlocated [here][original-repo]. The reasons for the divergence are summarized\n[here][divergent-opinion-issue].\n\n[original-repo]: https://github.com/whatyouhide/short_maps\n[divergent-opinion-issue]: https://github.com/whatyouhide/short_maps/issues/11","ref":"TinyMaps.html#module-credits"},{"type":"module","title":"Quick Reference: - TinyMaps","doc":"- Atom keys: `~M{a, b}` => `%{a: a, b: b}`\n- String keys: `~m{a, b}` => `%{\"a\" => a, \"b\" => b}`\n- Structs: `~M{%Person id, name}` => `%Person{id: id, name: name}`\n- Pinned variables: `~M{^a, b}` => `%{a: ^a, b: b}`\n- Ignore matching: `~M{_a, b}` => `%{a: _a, b: b}`\n- Map update (strings or atoms): `~M{old|a, b, c}` => `%{old|a: a, b: b, c: c}`\n- Struct update: `~M{%Person old_struct|name} => %Person{old_struct|name: name}`\n- Mixed mode: `~M{a, b: b_alt}` => `%{a: a, b: b_alt}`\n- Expressions: `~M{a, b: a + 1}` => `%{a: a, b: a + 1}`\n- Zero-arity: `~M{a, b()}` => `%{a: a, b: b()}`\n- Modifiers: `~m{blah}a == ~M{blah}` or `~M{blah}s == ~m{blah}`\n\n**Note**: you must `import TinyMaps` for the sigils to work.","ref":"TinyMaps.html#module-quick-reference"},{"type":"macro","title":"TinyMaps.sigil_M/2","doc":"Expands an atom-keyed map with the given keys bound to variables with the same\nname.\n\nBecause `~M` operates on atoms, it is compatible with Structs.","ref":"TinyMaps.html#sigil_M/2"},{"type":"macro","title":"Examples: - TinyMaps.sigil_M/2","doc":"# Map construction:\n    iex> tty = \"/dev/ttyUSB0\"\n    ...> baud = 19200\n    ...> device = ~M{tty, baud}\n    %{baud: 19200, tty: \"/dev/ttyUSB0\"}\n\n    # Map Update:\n    ...> baud = 115200\n    ...> %{device|baud}\n    %{baud: 115200, tty: \"/dev/ttyUSB0\"}\n\n    # Struct Construction\n    iex> id = 100\n    ...> ~M{%Person id}\n    %Person{id: 100, other_key: :default_val}","ref":"TinyMaps.html#sigil_M/2-examples"},{"type":"macro","title":"TinyMaps.sigil_m/2","doc":"Expands to a string keyed map where the keys are a string containing the\nvariable names, e.g. `~m{name}` expands to `%{\"name\" => name}`.\n\nSome common uses of `~m` are when working with JSON and Regex captures, which\nuse exclusively string keys in their maps.\n\n    # JSON example:\n    # Here, `~m{name, age}` expands to `%{\"name\" => name, \"age\" => age}`\n    iex> ~m{name, age} = Poison.decode!(\"{\"name\": \"Chris\",\"age\": \"old\"}\")\n    %{\"name\" => \"Chris\", \"age\" => \"old\"}\n    ...> name\n    \"Chris\"\n    ...> age\n    \"old\"\n\n\nSee the README for extended syntax and usage.","ref":"TinyMaps.html#sigil_m/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}